# Fluxterm

[![PyPI version](https://badge.fury.io/py/fluxterm.svg)](https://badge.fury.io/py/fluxterm)

> 🦩️ I find this highly ridulous. And highly excellent.

Flux... from a terminal! This is a small terminal application that will provide a handle to interact with Flux, but also other useful UI interactions that are nice to have. We currently have:

- A simple code browser
- A flux jobs interface to see (and possibly TBA interact) with jobs
- A flux cheat sheet for quick reference
- Fortune and wisdom from flux bird, the pink bird who knows things.

Coming soon:

- Interactive jobs table

## Screenshots

The application enters with a code browser for the present working directory.
The code browser is handy for navigating around your current directory of files.

![https://github.com/converged-computing/fluxterm/blob/main/docs/img/code-browser.png?raw=true](https://github.com/converged-computing/fluxterm/blob/main/docs/img/code-browser.png?raw=true)

The cheat sheets isn't the complete Flux documentation, but offers a quick, command line reference.

![https://github.com/converged-computing/fluxterm/blob/main/docs/img/cheat-sheet.png?raw=true](https://github.com/converged-computing/fluxterm/blob/main/docs/img/cheat-sheet.png?raw=true)

Every view also has a light mode (we default to dark).

![https://github.com/converged-computing/fluxterm/blob/main/docs/img/cheat-sheet-light.png?raw=true](https://github.com/converged-computing/fluxterm/blob/main/docs/img/cheat-sheet-light.png?raw=true)

The jobs table provides a quick interface to view flux jobs. We plan to add more interactivity to this,
for example, clicking a flux job to get more metadata or output.

![https://github.com/converged-computing/fluxterm/blob/main/docs/img/jobs-table.png?raw=true](https://github.com/converged-computing/fluxterm/blob/main/docs/img/jobs-table.png?raw=true)

Finally, if you ask for help? You get to talk with the "pink bird who knows things" Flux Bird.

![https://github.com/converged-computing/fluxterm/blob/main/docs/img/flux-bird.png?raw=true](https://github.com/converged-computing/fluxterm/blob/main/docs/img/flux-bird.png?raw=true)


If you'd like a feature added, please [let us know](https://github.com/converged-computing/fluxterm)!
It is currently bare bones, and development of this project will happen per user request.

## TODO

- Job table interactivity

## License

HPCIC DevTools is distributed under the terms of the MIT license.
All new contributions must be made under this license.

See [LICENSE](https://github.com/converged-computing/cloud-select/blob/main/LICENSE),
[COPYRIGHT](https://github.com/converged-computing/cloud-select/blob/main/COPYRIGHT), and
[NOTICE](https://github.com/converged-computing/cloud-select/blob/main/NOTICE) for details.

SPDX-License-Identifier: (MIT)

LLNL-CODE- 842614
